==> react-datepicker-2.1.0-0.jar: cljsjs/react-datepicker/common/react-datepicker.ext.js <==
/***
 * Externs manually updated from https://unpkg.com/react-datepicker@2.1.0/es/index.js
 */
var DatePicker = {
    "default": {
        "propTypes": {
            "onInputClick": {
                "isRequired": function () {}
            },
            "adjustDateOnChange": {
                "isRequired": function () {}
            },
            "allowSameDay": {
                "isRequired": function () {}
            },
            "autoComplete": {
                "isRequired": function () {}
            },
            "autoFocus": {
                "isRequired": function () {}
            },
            "calendarClassName": {
                "isRequired": function () {}
            },
            "children": {
                "isRequired": function () {}
            },
            "className": {
                "isRequired": function () {}
            },
            "customInput": {
                "isRequired": function () {}
            },
            "customInputRef": {
                "isRequired": function () {}
            },
            "dateFormat": {
                "isRequired": function () {}
            },
            "dateFormatCalendar": {
                "isRequired": function () {}
            },
            "dayClassName": {
                "isRequired": function () {}
            },
            "disabled": {
                "isRequired": function () {}
            },
            "disabledKeyboardNavigation": {
                "isRequired": function () {}
            },
            "dropdownMode": {
                "isRequired": function () {}
            },
            "endDate": {
                "isRequired": function () {}
            },
            "excludeDates": {
                "isRequired": function () {}
            },
            "filterDate": {
                "isRequired": function () {}
            },
            "fixedHeight": {
                "isRequired": function () {}
            },
            "formatWeekNumber": {
                "isRequired": function () {}
            },
            "highlightDates": {
                "isRequired": function () {}
            },
            "id": {
                "isRequired": function () {}
            },
            "includeDates": {
                "isRequired": function () {}
            },
            "includeTimes": {
                "isRequired": function () {}
            },
            "injectTimes": {
                "isRequired": function () {}
            },
            "inline": {
                "isRequired": function () {}
            },
            "isClearable": {
                "isRequired": function () {}
            },
            "locale": {
                "isRequired": function () {}
            },
            "maxDate": {
                "isRequired": function () {}
            },
            "minDate": {
                "isRequired": function () {}
            },
            "monthSelectedIn": {
                "isRequired": function () {}
            },
            "monthsShown": {
                "isRequired": function () {}
            },
            "name": {
                "isRequired": function () {}
            },
            "onBlur": {
                "isRequired": function () {}
            },
            "onChange": {
                "isRequired": function () {}
            },
            "onSelect": {
                "isRequired": function () {}
            },
            "onWeekSelect": {
                "isRequired": function () {}
            },
            "onClickOutside": {
                "isRequired": function () {}
            },
            "onChangeRaw": {
                "isRequired": function () {}
            },
            "onFocus": {
                "isRequired": function () {}
            },
            "onKeyDown": {
                "isRequired": function () {}
            },
            "onMonthChange": {
                "isRequired": function () {}
            },
            "onYearChange": {
                "isRequired": function () {}
            },
            "openToDate": {
                "isRequired": function () {}
            },
            "peekNextMonth": {
                "isRequired": function () {}
            },
            "placeholderText": {
                "isRequired": function () {}
            },
            "popperProps": {
                "isRequired": function () {}
            },
            "popperContainer": {
                "isRequired": function () {}
            },
            "popperClassName": {
                "isRequired": function () {}
            },
            "popperModifiers": {
                "isRequired": function () {}
            },
            "popperPlacement": {
                "isRequired": function () {}
            },
            "preventOpenOnFocus": {
                "isRequired": function () {}
            },
            "readOnly": {
                "isRequired": function () {}
            },
            "required": {
                "isRequired": function () {}
            },
            "scrollableYearDropdown": {
                "isRequired": function () {}
            },
            "scrollableMonthYearDropdown": {
                "isRequired": function () {}
            },
            "selected": {
                "isRequired": function () {}
            },
            "selectsEnd": {
                "isRequired": function () {}
            },
            "selectsStart": {
                "isRequired": function () {}
            },
            "showMonthDropdown": {
                "isRequired": function () {}
            },
            "showMonthYearDropdown": {
                "isRequired": function () {}
            },
            "showWeekNumbers": {
                "isRequired": function () {}
            },
            "showYearDropdown": {
                "isRequired": function () {}
            },
            "forceShowMonthNavigation": {
                "isRequired": function () {}
            },
            "showDisabledMonthNavigation": {
                "isRequired": function () {}
            },
            "startDate": {
                "isRequired": function () {}
            },
            "startOpen": {
                "isRequired": function () {}
            },
            "tabIndex": {
                "isRequired": function () {}
            },
            "timeCaption": {
                "isRequired": function () {}
            },
            "title": {
                "isRequired": function () {}
            },
            "todayButton": {
                "isRequired": function () {}
            },
            "useWeekdaysShort": {
                "isRequired": function () {}
            },
            "utcOffset": {
                "isRequired": function () {}
            },
            "renderCustomHeader": {
                "isRequired": function () {}
            },
            "renderDayContents": {
                "isRequired": function () {}
            },
            "inlineFocusSelectedMonth": {
                "isRequired": function () {}
            },
            "value": {
                "isRequired": function () {}
            },
            "weekLabel": {
                "isRequired": function () {}
            },
            "withPortal": {
                "isRequired": function () {}
            },
            "yearDropdownItemNumber": {
                "isRequired": function () {}
            },
            "shouldCloseOnSelect": {
                "isRequired": function () {}
            },
            "showTimeSelect": {
                "isRequired": function () {}
            },
            "showTimeSelectOnly": {
                "isRequired": function () {}
            },
            "timeFormat": {
                "isRequired": function () {}
            },
            "timeIntervals": {
                "isRequired": function () {}
            },
            "minTime": {
                "isRequired": function () {}
            },
            "maxTime": {
                "isRequired": function () {}
            },
            "excludeTimes": {
                "isRequired": function () {}
            },
            "useShortMonthInDropdown": {
                "isRequired": function () {}
            },
            "clearButtonTitle": {
                "isRequired": function () {}
            }
        }
    }
};

DatePicker.default.prototype = {
    "render": function () {},
    "componentWillReceiveProps": function () {},
    "componentWillUnmount": function () {},
    "componentDidUpdate": function () {}
};

==> react-datepicker-2.3.0-0.jar: cljsjs/react-datepicker/common/react-datepicker.ext.js <==
/***
 * Externs manually updated from https://unpkg.com/react-datepicker@2.3.0/es/index.js
 */
var DatePicker = {
    "default": {
        "propTypes": {
            "onInputClick": {
                "isRequired": function () {}
            },
            "adjustDateOnChange": {
                "isRequired": function () {}
            },
            "allowSameDay": {
                "isRequired": function () {}
            },
            "autoComplete": {
                "isRequired": function () {}
            },
            "autoFocus": {
                "isRequired": function () {}
            },
            "calendarClassName": {
                "isRequired": function () {}
            },
            "children": {
                "isRequired": function () {}
            },
            "className": {
                "isRequired": function () {}
            },
            "customInput": {
                "isRequired": function () {}
            },
            "customInputRef": {
                "isRequired": function () {}
            },
            "dateFormat": {
                "isRequired": function () {}
            },
            "dateFormatCalendar": {
                "isRequired": function () {}
            },
            "dayClassName": {
                "isRequired": function () {}
            },
            "disabled": {
                "isRequired": function () {}
            },
            "disabledKeyboardNavigation": {
                "isRequired": function () {}
            },
            "dropdownMode": {
                "isRequired": function () {}
            },
            "endDate": {
                "isRequired": function () {}
            },
            "excludeDates": {
                "isRequired": function () {}
            },
            "filterDate": {
                "isRequired": function () {}
            },
            "fixedHeight": {
                "isRequired": function () {}
            },
            "formatWeekNumber": {
                "isRequired": function () {}
            },
            "highlightDates": {
                "isRequired": function () {}
            },
            "id": {
                "isRequired": function () {}
            },
            "includeDates": {
                "isRequired": function () {}
            },
            "includeTimes": {
                "isRequired": function () {}
            },
            "injectTimes": {
                "isRequired": function () {}
            },
            "inline": {
                "isRequired": function () {}
            },
            "isClearable": {
                "isRequired": function () {}
            },
            "locale": {
                "isRequired": function () {}
            },
            "maxDate": {
                "isRequired": function () {}
            },
            "minDate": {
                "isRequired": function () {}
            },
            "monthSelectedIn": {
                "isRequired": function () {}
            },
            "monthsShown": {
                "isRequired": function () {}
            },
            "name": {
                "isRequired": function () {}
            },
            "onBlur": {
                "isRequired": function () {}
            },
            "onChange": {
                "isRequired": function () {}
            },
            "onSelect": {
                "isRequired": function () {}
            },
            "onWeekSelect": {
                "isRequired": function () {}
            },
            "onClickOutside": {
                "isRequired": function () {}
            },
            "onChangeRaw": {
                "isRequired": function () {}
            },
            "onFocus": {
                "isRequired": function () {}
            },
            "onKeyDown": {
                "isRequired": function () {}
            },
            "onMonthChange": {
                "isRequired": function () {}
            },
            "onYearChange": {
                "isRequired": function () {}
            },
            "openToDate": {
                "isRequired": function () {}
            },
            "peekNextMonth": {
                "isRequired": function () {}
            },
            "placeholderText": {
                "isRequired": function () {}
            },
            "popperProps": {
                "isRequired": function () {}
            },
            "popperContainer": {
                "isRequired": function () {}
            },
            "popperClassName": {
                "isRequired": function () {}
            },
            "popperModifiers": {
                "isRequired": function () {}
            },
            "popperPlacement": {
                "isRequired": function () {}
            },
            "preventOpenOnFocus": {
                "isRequired": function () {}
            },
            "readOnly": {
                "isRequired": function () {}
            },
            "required": {
                "isRequired": function () {}
            },
            "scrollableYearDropdown": {
                "isRequired": function () {}
            },
            "scrollableMonthYearDropdown": {
                "isRequired": function () {}
            },
            "selected": {
                "isRequired": function () {}
            },
            "selectsEnd": {
                "isRequired": function () {}
            },
            "selectsStart": {
                "isRequired": function () {}
            },
            "showMonthDropdown": {
                "isRequired": function () {}
            },
            "showMonthYearDropdown": {
                "isRequired": function () {}
            },
            "showWeekNumbers": {
                "isRequired": function () {}
            },
            "showYearDropdown": {
                "isRequired": function () {}
            },
            "forceShowMonthNavigation": {
                "isRequired": function () {}
            },
            "showDisabledMonthNavigation": {
                "isRequired": function () {}
            },
            "startDate": {
                "isRequired": function () {}
            },
            "startOpen": {
                "isRequired": function () {}
            },
            "tabIndex": {
                "isRequired": function () {}
            },
            "timeCaption": {
                "isRequired": function () {}
            },
            "title": {
                "isRequired": function () {}
            },
            "todayButton": {
                "isRequired": function () {}
            },
            "useWeekdaysShort": {
                "isRequired": function () {}
            },
            "utcOffset": {
                "isRequired": function () {}
            },
            "renderCustomHeader": {
                "isRequired": function () {}
            },
            "renderDayContents": {
                "isRequired": function () {}
            },
            "inlineFocusSelectedMonth": {
                "isRequired": function () {}
            },
            "value": {
                "isRequired": function () {}
            },
            "weekLabel": {
                "isRequired": function () {}
            },
            "withPortal": {
                "isRequired": function () {}
            },
            "yearDropdownItemNumber": {
                "isRequired": function () {}
            },
            "shouldCloseOnSelect": {
                "isRequired": function () {}
            },
            "showTimeSelect": {
                "isRequired": function () {}
            },
            "showTimeSelectOnly": {
                "isRequired": function () {}
            },
            "timeFormat": {
                "isRequired": function () {}
            },
            "timeIntervals": {
                "isRequired": function () {}
            },
            "minTime": {
                "isRequired": function () {}
            },
            "maxTime": {
                "isRequired": function () {}
            },
            "excludeTimes": {
                "isRequired": function () {}
            },
            "useShortMonthInDropdown": {
                "isRequired": function () {}
            },
            "clearButtonTitle": {
                "isRequired": function () {}
            },
            "strictParsing": {
                "isRequired": function () {}
            },
            "showTimeInput": {
                "isRequired": function () {}
            },
            "showMonthYearPicker": {
                "isRequired": function () {}
            },
            "timeInputLabel": {
                "isRequired": function () {}
            },
            "onDayMouseEnter": {
                "isRequired": function () {}
            },
            "onMonthMouseLeave": {
                "isRequired": function () {}
            }
        }
    }
};

DatePicker.default.prototype = {
    "render": function () {},
    "componentWillReceiveProps": function () {},
    "componentWillUnmount": function () {},
    "componentDidUpdate": function () {}
};
